#! /bin/bash
# Copyright 1999-2009, Intel(R) Corporation, All Rights Reserved
# This script uninstalls Intel(R) compilers and related packages.


# ------------------------------------------------------------------------
#Check if the USER is root
IS_USER_ROOT ()
{
   VPRINT "IS_USER_ROOT()"
   if [ "${USER}x" != "rootx" ] ; then
       if [ ! -w /dev ] ; then
            ROOT_USER=0
       else
            ROOT_USER=1
       fi
   else
          ROOT_USER=1
   fi
}

# ------------------------------------------------------------------------
## Check whether RPM is present or not.
IS_RPM_PRESENT ()
{
    VPRINT "IS_RPM_PRESENT()"
    #Check if we can get a shared lock on rpm database
    rpm -q rpm &> /dev/null
    RPM_NOT_FOUND=$?
}


# ------------------------------------------------------------------------
# Figure out the location of intel_sdp_products database.
GET_FLATFILE_DB_LOCATION ()
{
    VPRINT "GET_FLATFILE_DB_LOCATION()"
    if [ "$ROOT_USER" = 1 ]; then
         DB_DIR_PREFIX="/opt/intel"
    else
         DB_DIR_PREFIX=""
         DB_DIR_PREFIX="$(echo ~)/intel"
         if [ "$DB_DIR_PREFIX" = "/root" ] || [ "$DB_DIR_PREFIX" = "/" ] || [ "$DB_DIR_PREFIX" = "" ] || [ "$DB_DIR_PREFIX" = "/intel" ]; then
             DB_DIR_PREFIX="/opt/intel"
         fi
    fi

    if [ "$INTEL_SDP_PRODUCTS_DB" = "" ]; then
           INTEL_SDP_PRODUCTS_DB="$DB_DIR_PREFIX/intel_sdp_products.db"
    fi
}

# ------------------------------------------------------------------------
# Check if starting uninstall from inside the uninstall directory
# If true, then issue a warning and exit the uninstall program
CHECK_LOCAL_UNINSTALL ()
{
    VPRINT "CHECK_LOCAL_UNINSTALL()"
    CMD="$0"
    DIRNAME_CMD="$(dirname $0)"
    if [ "$DIRNAME_CMD" = "" ] || [ "$DIRNAME_CMD" = "." ] || [ "$DIRNAME_CMD" = "./" ]; then
	# error - start the program outside of the product directory
        echo "$UNS_STRING_1"
	exit 1
    fi
}

# ------------------------------------------------------------------------
# remove C++ compiler and its components
UNINSTALL_CPROC_RPM_AND_ITS_DEPENDENCIES ()
{
    VPRINT "UNINSTALL_CPROC_RPM_AND_ITS_DEPENDENCIES()"
    local RESULT1="$(rpm -qa  | egrep -e 'intel-cpro' | egrep -i ${PKGNUM} | egrep -i ${VERSION} | egrep -e 'mkl' -e 'ipp')"
    local RESULT2="$(rpm -qa  | egrep -e 'intel-cpro' | egrep -i ${PKGNUM} | egrep -i ${VERSION} | egrep -e 'tbb')"
    VPRINT "Cpro C/C++ RPM check for mkl/tbb/ipp installs - RESULT1=<$RESULT1>"
    if [ -n "$RESULT2" ]; then
        echo "$UNS_STRING_2"
	read CONTINUE
        RETURN_VAL=2
	RPM_LIST=""
        return
    fi
    if [ -n "$RESULT1" ]; then
	# error - cannot remove c/c++ until dependent product components are removed first
	local THIS_RPM_ARCH=$(rpm -q --queryformat %{ARCH} $CHOSEN_RPM)
	local THIS_OTHER_RPM_ARCH=""
	for THIS_OTHER_RPM in $RESULT1
	do
            THIS_OTHER_RPM_ARCH=$(rpm -q --queryformat %{ARCH} $THIS_OTHER_RPM)
	    if [ "$THIS_OTHER_RPM_ARCH" = "$THIS_RPM_ARCH" ]; then    
                echo "$UNS_STRING_2"
	        read CONTINUE
                RETURN_VAL=2
		RPM_LIST=""
                return
            fi
        done             
    fi
    # if fortran is installed do not remove shared C++ libraries
    # otherwise, remove them 
    local RESULT1="$(rpm -qa | egrep -e 'intel-cprof' | egrep -i ${PKGNUM}-${VERSION})"
    if [ -n "$RESULT1" ]; then
	# pre-code review version
	# RPM_LIST="$CHOSEN_RPM intel-cprocsdk${PKGNUM}-${VERSION}-1 intel-cproc${PKGNUM}-${VERSION}-1"
	# post-code review version - the second intel-cproc was redundant 
	RPM_LIST="$CHOSEN_RPM intel-cprocsdk${PKGNUM}-${VERSION}-1"
    else
	RPM_LIST="$CHOSEN_RPM intel-cprocsdk${PKGNUM}-${VERSION}-1 intel-cproc${PKGNUM}-${VERSION}-1"
	RPM_LIST="$RPM_LIST intel-cprolib${PKGNUM}-${VERSION}-1 intel-cprolibdev${PKGNUM}-${VERSION}-1"
    fi
    VPRINT "Starting RPM with args=<$USER_ARGUMENTS>"
    VPRINT "RPM_LIST=<$RPM_LIST>"
    rpm $USER_ARGUMENTS $RPM_LIST
    RETURN_VAL=$?
    RMP_LIST=""
}

# ------------------------------------------------------------------------
# remove Fortran compiler and its components
UNINSTALL_CPROF_RPM_AND_ITS_DEPENDENCIES ()
{
    VPRINT "UNINSTALL_CPROF_RPM_AND_ITS_DEPENDENCIES()"
    local RESULT1="$(rpm -qa  | egrep -e 'intel-cpro' | egrep -i ${PKGNUM}-${VERSION} | egrep -e 'mkl')"
    VPRINT "Cpro Fortran RPM check for mkl installs - RESULT1=<$RESULT1>"
    if [ -n "$RESULT1" ]; then
	# error - cannot remove fortran until dependent product components are removed first
	local THIS_RPM_ARCH=$(rpm -q --queryformat %{ARCH} $CHOSEN_RPM)
	local THIS_MKL_RPM_ARCH=""
	for THIS_MKL_RPM in $RESULT1
	do
            THIS_MKL_RPM_ARCH=$(rpm -q --queryformat %{ARCH} $THIS_MKL_RPM)
	    if [ "$THIS_MKL_RPM_ARCH" = "$THIS_RPM_ARCH" ]; then    
            echo "$UNS_STRING_3"
	        read CONTINUE
            RETURN_VAL=2
	    RPM_LIST=""
            return
        fi
        done             
    fi
    # see if C++ is installed - if so, do not remove shared C++ libs
    local RESULT1="$(rpm -qa | egrep -e 'intel-cproc' | egrep -i ${PKGNUM}-${VERSION} | egrep -v -e 'mkl' -e 'idb' -e 'tbb' -e 'ipp')"
    if [ -n "$RESULT1" ]; then
	RPM_LIST="$CHOSEN_RPM intel-cprofsdk${PKGNUM}-${VERSION}-1 intel-cproflib${PKGNUM}-${VERSION}-1"
    else
	RPM_LIST="$CHOSEN_RPM intel-cprofsdk${PKGNUM}-${VERSION}-1 intel-cproflib${PKGNUM}-${VERSION}-1"
	RPM_LIST="$RPM_LIST intel-cprolib${PKGNUM}-${VERSION}-1 intel-cprolibdev${PKGNUM}-${VERSION}-1"
    fi
    VPRINT "Starting RPM with args=<$USER_ARGUMENTS>"
    VPRINT "RPM_LIST=<$RPM_LIST>"
    rpm $USER_ARGUMENTS $RPM_LIST
    RETURN_VAL=$?
    RPM_LIST=""
}
# ------------------------------------------------------------------------
IS_OS_FEDORA_9 () 
{
	# return 1 for TRUE (OS is Redhat Fedora 9)
	# return 0 for FALSE (OS is NOT Redhat Fedora 9)

   local RELEASE_FILE=/etc/fedora-release
   local RELEASE_CONTENT_A="Fedora"
   local RELEASE_CONTENT_B="release 9"
   local RESULT_A
   local RESULT_B
   if [ -s $RELEASE_FILE ]; then
        RESULT_A=$(grep -i "$RELEASE_CONTENT_A" $RELEASE_FILE)
        RESULT_B=$(grep -i "$RELEASE_CONTENT_B" $RELEASE_FILE)
	if [ "$RESULT_A" != "" ] && [ "$RESULT_B" != "" ]; then
            OS_FEDORA_9=1
	    OS_NAME="Fedora Release 9"
	    # echo "... $OS_NAME detected"
	    return 1
        else
            OS_FEDORA_9=0	
	    # echo -n "."
	    return 0
        fi
   else
       OS_FEDORA_9=0	
       return 0
    fi
}

# ------------------------------------------------------------------------
# remove TBB Links 
REMOVE_TBB_LINKS ()
{
    VPRINT "REMOVE_TBB_LINKS()"
    local TBB_PURGE_DIR="${SCRIPT_DIR}/../../tbb"
    if [ ! -d $TBB_PURGE_DIR ]; then
        VPRINT "Cannot find TBB_PURGE_DIR"
    else
        pushd $TBB_PURGE_DIR 2> /dev/null > /dev/null
        VPRINT "Now in TBB_PURGE_DIR $TBB_PURGE_DIR --- pwd=`pwd`"
        echo "$UNS_STRING_22"
	#local FILEA=$(find . -type l -name 'bin' -print 2> /dev/null)
	#local FILE_CHECK=$(ls -l $FILEA | grep kernel)
	#if [ -n "$FILE_CHECK" ]; then
        #    rm -rf $FILEA 2> /dev/null
	#else
	#    VPRINT "No TBB 'bin' link file found"
	#fi
	local FILEB_LIST=$(find . -type l -name '*' -print 2> /dev/null)
	for FILEB in $FILEB_LIST
	do
	    local FILE_CHECK=$(ls -l $FILEB | grep kernel)
	    if [ -n "$FILE_CHECK" ]; then
                rm -rf $FILEB 2> /dev/null
	    else
	        VPRINT "No TBB symlink files found"
	    fi
	done
        popd 2> /dev/null > /dev/null
    fi
}

# ------------------------------------------------------------------------
# remove IPP Links - only needed for non-RPM
REMOVE_IPP_LINKS ()
{
    VPRINT "REMOVE_IPP_LINKS()"
    local IPP_PURGE_DIR="${SCRIPT_DIR}/../../ipp"
    if [ ! -d $IPP_PURGE_DIR ]; then
        VPRINT "Cannot find IPP_PURGE_DIR"
    else
        pushd $IPP_PURGE_DIR 2> /dev/null > /dev/null
        VPRINT "Now in IPP_PURGE_DIR $IPP_PURGE_DIR --- pwd=`pwd`"
        echo "$UNS_STRING_22"
        case "$ARCH" in
            i486 )
                 local INCLUDE_DIR="./ia32/include"
                 ;;
            ia64 )
                 local INCLUDE_DIR="./ia64/include"
                 ;;
            x86_64 )
                 local INCLUDE_DIR="./em64t/include"
                 ;;
	    dual)
                 local INCLUDE_DIR1="./ia32/include"
		 local INCLUDE_DIR2="./em64t/include"
                 ;;
            * )
                 VPRINT "No match for ARCH=<$ARCH> - defaulting to ia32"
                 local INCLUDE_DIR="./ia32/include"
                 ;;
        esac

	if [ "x$ARCH" == "xdual" ]; then
	    VPRINT "Removing $INCLUDE_DIR1 $INCLUDE_DIR2 ..."
	    [ -e "$INCLUDE_DIR1" ] && rm -rf "$INCLUDE_DIR1" &> /dev/null
	    [ -e "$INCLUDE_DIR2" ] && rm -rf "$INCLUDE_DIR2" &> /dev/null
        elif [ -e "$INCLUDE_DIR" ]; then
            VPRINT "Removing $INCLUDE_DIR ..."
            rm -rf "$INCLUDE_DIR" &> /dev/null
        else
            VPRINT "No IPP include link dir <$INCLUDE_DIR> found"
        fi
	
	[ -e "../.scripts" ] && rm -rf "../.scripts" &>/dev/null

        popd 2> /dev/null > /dev/null
    fi
}

# ------------------------------------------------------------------------
# remove IDB Links 
REMOVE_IDB_LINKS ()
{
    VPRINT "REMOVE_IDB_LINKS()"
    local IDB_PURGE_DIR="$SCRIPT_DIR/../../idb"
    if [ ! -d "$IDB_PURGE_DIR" ]; then
        VPRINT "Cannot find IDB_PURGE_DIR $IDB_PURGE_DIR"
    else
        pushd $IDB_PURGE_DIR 2> /dev/null > /dev/null
        VPRINT "Now in IDB_PURGE_DIR - pwd=`pwd`"
        echo "$UNS_STRING_22"
        local FILEA=$(find . -name 'com.intel.debugger.help_1.0.0' -type l -print 2> /dev/null)
        if [ -z "$FILEA" ]; then
            VPRINT "Cannot file 'com.intel.debugger.help_1.0.0' link file"
        else
            rm -rf $FILEA 2> /dev/null 
        fi
	# following section obsolete with migration to new Eclipse
        #IS_OS_FEDORA_9
        #if [ "$OS_FEDORA_9" = 1 ]; then
        #    VPRINT "For webhelp removal, now in IDB_PURGE_DIR ${IDB_PURGE_DIR} --- pwd=`pwd`"
        #    local FILEA=$(find . -name 'webhelp' -type d -print 2> /dev/null)
        #    if [ -z "$FILEA" ]; then
        #        VPRINT "Cannot find file 'webhelp' directory"
        #    else
	#        if [ -s ${FILEA}/styles_l.css ]; then
        #            VPRINT "webhelp directory is $FILEA"
        #            rm -rf $FILEA 2> /dev/null 
        #        else
        #            VPRINT "Cannot find file 'webhelp' directory signature file 'styles_l.css'"
        #            VPRINT "webhelp not installed"
        #        fi
        #    fi
        #fi
        popd 2> /dev/null > /dev/null
    fi
}

# ------------------------------------------------------------------------
# Remove chosen RPM.
DISPLAY_RPM_MENU ()
{
    VPRINT "DISPLAY_RPM_MENU()"
    INDEX=0
    DISPLAY_HEADER=0
    #echo "$@"  
    for INSTALLED_RPM in $@ ; do
     	DISPLAY_HEADER=1
    done
    
    # display header
    if [ $DISPLAY_HEADER = "1" ] ; then
       VPRINT "$0: $LOCAL_VERSION"
       echo
       # which would you like to uninstall?
       echo "$UNS_STRING_4"
       DISPLAY_HEADER=0 
       # 0. uninstall all comp pro $PACKAGE_NUMBER components
       echo "$UNS_STRING_5 $PACKAGE_NUMBER" 
    fi

    for INSTALLED_RPM in $@ 
    do
	[ "x$(echo $INSTALLED_RPM | grep crypto 2>/dev/null)" == "x" ] || continue
        INDEX="$(($INDEX+1))"
	echo -n "$INDEX.   "
	# old RPM-data based display procedure
	# rpm -qi "$INSTALLED_RPM" | grep Summary | cut -d: -f2-3
	# end old method
	#
	# new method as employed within non-RPM uninstall
        # PACKAGEID="$(echo $PROD | cut -d':' -f2)"
        # RPMNAME="$(echo $PROD | cut -d':' -f3)"
        # LOCATION="$(echo $PROD | cut -d':' -f4)"
        # LOG_FILE="$(echo $PROD | cut -d':' -f5)"
        # UPDATE_DISPLAY_VARIABLES
	RPMNAME=$INSTALLED_RPM
	PACKAGEID=$THIS_PACKAGEID
        PRODUCT=$(echo "$RPMNAME" | grep -o -E "(intel-cproidb${PKGNUM}-${VERSION}|intel-cprotbblib${PKGNUM}-${VERSION}|intel-cproipplibdev${PKGNUM}-${VERSION}|intel-cpromklibdev|intel-cproc${PKGNUM}-${VERSION}|intel-cprof${PKGNUM}-${VERSION}|intel-cproipp${PKGNUM}lp32-${VERSION})")
	RPM_ARCH_TEST=$(rpm -q --queryformat %-{name}-%{version}-%{release}-%{arch}"\n" $RPMNAME)
	if [ -n "$RPM_ARCH_TEST" ]; then
	    I686_RESULT=$(echo $RPM_ARCH_TEST | grep i486)
	    IA64_RESULT=$(echo $RPM_ARCH_TEST | grep ia64)
	    X86_64_RESULT=$(echo $RPM_ARCH_TEST | grep x86_64)
	    NOARCH_RESULT=$(echo $RPM_ARCH_TEST | grep noarch)
	    if [ "$I686_RESULT" = "" ] && \
	       [ "$IA64_RESULT" = "" ] && \
	       [ "$NOARCH_RESULT" = "" ] && \
	       [ "$X86_64_RESULT" = "" ]; then
	        VPRINT "Warning - Architecture test results suspect"
	        ARCH=i486
	    elif [ -n "$I686_RESULT" ] && [ -n "$X86_64_RESULT" ]; then
	        ARCH=dual
	    elif [ -n "$I686_RESULT" ]; then
	        ARCH=i486
	    elif [ -n "$IA64_RESULT" ]; then
	        ARCH=ia64
	    elif [ -n "$X86_64_RESULT" ]; then
	        ARCH=x86_64
	    elif [ -n "$NOARCH_RESULT" ]; then
	        ARCH=noarch
	    fi
	else
	    ARCH=i486
	    VPRINT "Warning - Architecture test results suspect"
	fi
        VPRINT "DISPLAY_RPM_MENU() - RPMNAME=<$RPMNAME> - ARCH=<$ARCH>"
	UPDATE_DISPLAY_VARIABLES
	echo "$signon"
	if [ -n "$signon2" ]; then
	    echo -e "        $signon2"
	fi

	# is this C++?  
	local RESULT1=$(echo $INSTALLED_RPM  | egrep -e "intel-cproc${PKGNUM}-${VERSION}")
        VPRINT "DISPLAY_RPM_MENU() - C++ check - RESULT1=<$RESULT1>"
	if [ -n "$RESULT1" ]; then
	    # add note that this is required for c/c++ library components
	    local RESULT2=$(echo $@ | grep -e intel-cprotbblib${PKGNUM}-${VERSION} -e intel-cproipplibdev${PKGNUM}-${VERSION} -e intel-cpromklibdev${PKGNUM}-${VERSION} -e intel-cproipp${PKGNUM}lp32-${VERSION})
            VPRINT "DISPLAY_RPM_MENU() - C++  AND (MKL or TBB or IPP) check - RESULT2=<$RESULT2>"
	    if [ -n "$RESULT2" ]; then
                echo "$UNS_STRING_6"
            fi
	else
            # is this Fortran
	    local RESULT1=$(echo $INSTALLED_RPM  | egrep -e "intel-cprof${PKGNUM}-${VERSION}")
            VPRINT "DISPLAY_RPM_MENU() - Fortran check - RESULT1=<$RESULT1>"
	    if [ -n "$RESULT1" ]; then
	        # add note that this is required for fortran library components
	        local RESULT2=$(echo $@ | grep -e intel-cpromklibdev${PKGNUM}-${VERSION})
                VPRINT "DISPLAY_RPM_MENU() - Fortran AND MKL check - RESULT2=<$RESULT2>"
	        if [ -n "$RESULT2" ]; then
                    echo "$UNS_STRING_7"
	        fi 
	    fi 
        fi
    done

    echo ""
    MAX_INDEX=$INDEX
    if [ $MAX_INDEX -ge 1 ] &> /dev/null ; then
	# x. Exit
        echo "$UNS_STRING_8"
	# Please make a selection
    	echo -n "$UNS_STRING_9"
	REPEAT_LOOP=1
        while [ "$REPEAT_LOOP" = "1" ]
	do
    	    read CHOSEN_INDEX &> /dev/null
    	    if [ "$CHOSEN_INDEX" = x ] &>/dev/null ; then
		# Exiting ...
		echo "$UNS_STRING_10"
		TINI_SCRIPT
            fi  
    	    if [ -n "$CHOSEN_INDEX" ] && [ $CHOSEN_INDEX = 0 ]; then
                UNINSTALL_ALL_CHOICE=1
                UNINSTALL_ALL_RPM 
                TINI_SCRIPT
	    fi
    	    if [ $CHOSEN_INDEX -ge 1 ] &> /dev/null \
                && [ $CHOSEN_INDEX -le $MAX_INDEX ] &> /dev/null ; then
		REPEAT_LOOP=0
		seddiscrep="intel-cproc${PKGNUM}crypto_ipp-${VERSION}-1 "
		CHOSEN_RPM="$(echo $INSTALLED_RPM_LIST | sed -e"s/$seddiscrep//g" | \
		    cut -d' ' -f"$CHOSEN_INDEX")"
                VPRINT "DISPLAY_RPM_MENU() - CHOSEN_RPM=<$CHOSEN_RPM>"
		CHOSEN_FULL_NAME="$(rpm -qi $CHOSEN_RPM | \
		    grep Summary | cut -d: -f2-3)"
		DEFAULT_ARGUMENTS="-e --allmatches"
		echo
                
		# what RPM options do you want to use to uninstall
		echo "$UNS_STRING_11" "this component?"
		#echo -n "$CHOSEN_FULL_NAME [$DEFAULT_ARGUMENTS]?   :   "
		echo -n "[$DEFAULT_ARGUMENTS]?   :   "
		read USER_ARGUMENTS &> /dev/null
		if [ -z "$USER_ARGUMENTS" ] &> /dev/null ; then
	    	    USER_ARGUMENTS="$DEFAULT_ARGUMENTS"
		fi
		# uninstalling $CHOSEN_FULL_NAME
		# echo "$UNS_STRING_12 $CHOSEN_FULL_NAME"
		# Working ...
		echo "$UNS_STRING_22"
             else
	             REPEAT_LOOP=1
	             echo
	         # inappropriate choice. try 0, x, or the number of a component
	             echo "$UNS_STRING_15"
	             # which would you like to uninstall?
		     break
    	             # echo -n "$UNS_STRING_4"
            fi
	    # assume we have a good choice if we are here
            case "$CHOSEN_RPM" in
                 intel-cproc${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $CHOSEN_RPM"
                     UNINSTALL_CPROC_RPM_AND_ITS_DEPENDENCIES
		     # break
                     ;;
                 intel-cprof${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $CHOSEN_RPM"
	             UNINSTALL_CPROF_RPM_AND_ITS_DEPENDENCIES
		     # break
                     ;;
                 intel-cproidb${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $CHOSEN_RPM"
                     REMOVE_IDB_LINKS
		     if [ "$ARCH" != "ia64" ]; then
		         IDBCDT_RESULT=$(rpm -qa | grep intel-cproidbcdt${PKGNUM}-${VERSION})
			 if [ -n "$IDBCDT_RESULT" ]; then
 	                     RPM_LIST="$CHOSEN_RPM intel-cproidbsdk${PKGNUM}-${VERSION} intel-cproidbcdt${PKGNUM}-${VERSION}"
		         else
			     VPRINT "No idbcdt found ... must have been a Fortran IDB install"
 	                     RPM_LIST="$CHOSEN_RPM intel-cproidbsdk${PKGNUM}-${VERSION}"
		         fi
		     else
			 VPRINT "No IDBCDT for IA64"
 	                 RPM_LIST="$CHOSEN_RPM intel-cproidbsdk${PKGNUM}-${VERSION}"
		     fi
                     ;;
                 intel-cpromklibdev${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $CHOSEN_RPM"
	             RPM_LIST="$CHOSEN_RPM intel-cpromklib${PKGNUM}-${VERSION} intel-cpromkl${PKGNUM}-${VERSION}"
                     ;;
                 intel-cproipplibdev${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $CHOSEN_RPM"
                     RPM_LIST="$CHOSEN_RPM intel-cproipp${PKGNUM}-${VERSION} intel-cproipplib${PKGNUM}-${VERSION}"
		     [ "x$CPIPP_INSTALLED" == "x1" ] && RPM_LIST="$RPM_LIST intel-cproc${PKGNUM}crypto_ipp-${VERSION}"
                     ;;
                 intel-cprotbblib${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $CHOSEN_RPM"
                     REMOVE_TBB_LINKS
	             RPM_LIST="$CHOSEN_RPM intel-cprotbblibdev${PKGNUM}-${VERSION}"
                     ;;
                 intel-cproipp${PKGNUM}lp32-${VERSION}* )
	             VPRINT "Uninstalling $CHOSEN_RPM"
                     RPM_LIST="$CHOSEN_RPM"
                     [ "x$CPIPP_INSTALLED" == "x1" ] && RPM_LIST="$RPM_LIST intel-cproc${PKGNUM}crypto_ipp-${VERSION}"
                     ;;
                 * )
	             VPRINT "No match for CHOSEN_RPM=<$CHOSEN_RPM>"
	             RPM_LIST=""
                     continue
                     ;;
             esac
         
	     # RPM_LIST should only be empty if compilers were uninstalled
             if [ "$RPM_LIST" != "" ]; then
                 touch $RPM_UNS_LOG
                 VPRINT "Executing this command: "
                 VPRINT "rpm $USER_ARGUMENTS $RPM_LIST 2> $RPM_UNS_LOG"
                 rpm $USER_ARGUMENTS $RPM_LIST 2> $RPM_UNS_LOG
                 RETURN_VAL=$?
	     fi
	     if [ "$RETURN_VAL" = 0 ]; then
	         # Uninstall successful
	         echo "$UNS_STRING_13"
	         rm -rf $RPM_UNS_LOG 2> /dev/null
	     elif [ "$RETURN_VAL" = 1 ]; then
	         # Uninstall unsuccessful
	         echo "$UNS_STRING_14"
	         VPRINT "Details in UNINSTALL_LOG $RPM_UNS_LOG"
	         VPRINT "`cat $RPM_UNS_LOG`"
	         rm -rf $RPM_UNS_LOG 2> /dev/null
	     else 
	         # assume that it was a case of Compiler prerequisite uninstall skip
		 VPRINT "Skipping uninstall of required component (C++ or Fortran)"
	     fi
	     REPEAT_LOOP=0
	     RPM_LIST=""
    done
    fi
}

# ------------------------------------------------------------------------
# process rpm install list
RPM_BASED_UNINSTALLATION ()
{
    VPRINT "RPM_BASED_UNINSTALLATION()"
    echo
    while INSTALLED_RPM_LIST="$(rpm -qa | grep -e intel-cproc${PKGNUM}-${VERSION} -e intel-cprof${PKGNUM}-${VERSION} -e intel-cproidb${PKGNUM}-${VERSION} -e intel-cpromklibdev${PKGNUM}-${VERSION} -e intel-cproipplibdev${PKGNUM}-${VERSION} -e intel-cprotbblib${PKGNUM}-${VERSION} -e intel-cproipp${PKGNUM}lp32-${VERSION} | sort | uniq)" && [ -n "$INSTALLED_RPM_LIST" ] ; do
      	echo
	VPRINT "INSTALLED_RPM_LIST=<$INSTALLED_RPM_LIST>"
    	DISPLAY_RPM_MENU $INSTALLED_RPM_LIST
    done
   
    ## This special call is required if all compiler components have 
    ## been uninstalled but EP has not been uninstalled yet.
    # - is this is now obsolete ?
    DISPLAY_RPM_MENU
    echo
    # no Cpro $PACKAGE_NUMBER compilers or components found
    echo "$UNS_STRING_16 $PACKAGE_NUMBER"
    echo
    if [ -f "$INTEL_SDP_PRODUCTS_DB" ]; then
	VAR="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:')"
	if [ -n "$VAR" ]; then
    		echo
		# some may have been installed as non-root or without RPM
		# use uninstaller for that product version
                echo "$UNS_STRING_17"
    		echo
	fi
    fi
    	
}

# ------------------------------------------------------------------------
# Main routine for flat file based uninstallation.
NON_RPM_BASED_UNINSTALLATION ()
{
    VPRINT "NON_RPM_BASED_UNINSTALLATION()"

# while INSTALLED_RPM_LIST="$(rpm -qa | grep -e intel-cproc${PKGNUM}-${VERSION} -e intel-cprof${PKGNUM}-${VERSION} -e intel-cproidb${PKGNUM}-${VERSION} -e intel-cpromklibdev${PKGNUM}-${VERSION} -e intel-cproipplibdev${PKGNUM}-${VERSION} -e intel-cprotbb${PKGNUM}-${VERSION} | sort | uniq)" && [ -n "$INSTALLED_RPM_LIST" ] ; do

        if [ -f "$INTEL_SDP_PRODUCTS_DB" ]; then
		while VAR="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' )" && [ -n "$VAR" ]; 
		do
    			DISPLAY_NON_RPM_MENU
		done
        	DISPLAY_NON_RPM_MENU
	else
		if [ "$ROOT_USER" = 0 ] ; then
		        echo 
			# no non-RPM installed products found
			# if installed as root, you must become root to uninstall them
			echo "$UNS_STRING_18"
			# echo "$PACKAGE_NUMBER"
			echo
		fi
		# exit
                TINI_SCRIPT
	fi
}

# ------------------------------------------------------------------------
# remove shell directories left behind
REMOVE_EMPTY_DIRS ()
{
    VPRINT "REMOVE_EMPTY_DIRS() - ARGS=<$@>"
    local rootnodes="$@"
    local childnodes=''
    if [ -n "$rootnodes" ] ; then
        # find empty directories
        childnodes=$(find $rootnodes -empty -type d 2>&1)
        # if find returns an error
        if (($?)) ; then
            # display error messages
            # echo -e "$childnodes" | \
            #     grep 'find:' | sed s@'^'@'REMOVE_EMPTY_DIRS: '@g 
            # strip error messages from list of empty directories
            childnodes=$(echo "$childnodes" | grep -v 'find:')
        fi
        if [ -n "$childnodes" ] ; then
            # remove empty directories
            rmdir -p $childnodes > /dev/null 2>&1
        fi
    fi
}

# ------------------------------------------------------------------------
# create a version of arg1 file in arg2 that contains lins that are NOT directories
DIR_STRIP ()
{
    VPRINT "DIR_STRIP()"
    local INFILE=$1
    local OUTFILE=$2
    local DATA_LINE=""
    if [ ! -s $INFILE ]; then
	# no arg1 found
        echo "$UNS_STRING_19"
	TINI_SCRIPT
    fi 
    touch $OUTFILE
    if [ ! -e $OUTFILE ]; then
	# cannot create temporary file
        echo "$UNS_STRING_20"
	echo "$OUTFILE"
	TINI_SCRIPT
    fi
    # exec < $INFILE
    while read DATA_LINE
    do
        if [ ! -d $DATA_LINE ]; then
	    echo "$DATA_LINE" >> $OUTFILE
        else
	    VPRINT "DIR_STRIP() - Discarding entry <$DATA_LINE>"
        fi
    done < $INFILE
}

# ------------------------------------------------------------------------
# remove a specific component via non-rpm means
UNINSTALL_NON_RPM () 
{
    local PROD="$1"
    VPRINT "UNINSTALL_NON_RPM() - PROD = <$PROD>"
    local PACKAGEID="$(echo $PROD | cut -d':' -f2)"
    local RPMNAME="$(echo $PROD | cut -d':' -f3)"
    local LOCATION="$(echo $PROD | cut -d':' -f4)"
    local FILE="$(echo $PROD | cut -d':' -f5)"
   
    # check if this is a TBB install ... if so, need to clean non-RPM symlinks
    # RESULT1=$(echo $RPMNAME | grep 'intel-cprotbblib${PKGNUM}-${VERSION}')
    # if [ -n "$RESULT1" ]; then
    #     local THIS_IS_TBB=1
    # else
    #     local THIS_IS_TBB=0
    # fi

    # check if this is a IDB install ... if so, need to clean non-RPM symlinks
    #RESULT1=$(echo $RPMNAME | grep 'intel-cproidb${PKGNUM}-${VERSION}')
    #if [ -n "$RESULT1" ]; then
    #    local THIS_IS_IDB=1
    #else
    #    local THIS_IS_IDB=0
    #fi

    if [ "$DEFAULT_MODE" != 1 ]; then
	# uninstalling $RPMNAME
	# echo "$UNS_STRING_21 $RPMNAME"
	# echo "$UNS_STRING_21 $RPMNAME"
	echo "$UNS_STRING_22"
	# removing files
	echo "$UNS_STRING_22"
    fi
   
    if [ ! -f "$FILE" ]; then
	echo 
	echo
	# $0: UNINSTALL_NON_RPM - ERROR - Uninstallation cannot continue for this component
	echo "$UNS_STRING_23"
	# echo Missing $FILE
	echo "$UNS_STRING_24 $FILE"
	return
    fi

    VPRINT "Processing list file ... line total (`wc -l $FILE 2> /dev/null`)"
    while read VAR;  do
        if [ ! -d "$VAR" ]; then
            if [ "$DEBUG_MODE" != 1 ]; then 
                rm -f "$VAR"
	    else
                if [ ! -e $VAR ]; then echo "<$VAR> file not found"; fi
                rm -f "$VAR"
		echo -n "."
                if [ -e $VAR ]; then echo "<$VAR> file not found removed"; fi
            fi
        fi
    done < $FILE
    rm -f $FILE
    
    #if [ "$THIS_IS_TBB" = 1 ]; then
    #	echo 
    # Removing TBB non-RPM symlinks ...
    #	echo "$UNS_STRING_22"
    #	REMOVE_TBB_LINKS
    #fi

    #if [ "$THIS_IS_IDB" = 1 ]; then
    # Removing IDB non-RPM symlinks ...
    #   echo "$UNS_STRING_22"
    #	REMOVE_IDB_LINKS
    #    THIS_IS_IDB=0
    #fi

    if [ "$DEFAULT_MODE" != 1 ]; then
        # Removing only EMPTY directories ...
	echo "$UNS_STRING_27"
    fi
    REMOVE_EMPTY_DIRS "$LOCATION"

    M_PROD=$(echo $PROD | sed s@'/'@'\\/'@g)            
        sed "/$M_PROD/D" $INTEL_SDP_PRODUCTS_DB > $INTEL_SDP_PRODUCTS_DB.new

    mv "$INTEL_SDP_PRODUCTS_DB" "$INTEL_SDP_PRODUCTS_DB.old"
    mv "$INTEL_SDP_PRODUCTS_DB.new" "$INTEL_SDP_PRODUCTS_DB"
    #echo
}

# ------------------------------------------------------------------------
# manage non-rpm uninstall menu
DISPLAY_NON_RPM_MENU () 
{
    VPRINT "DISPLAY_NON_RPM_MENU()"
    ICC_IA32_INSTALLED=0		# initialize all installed component flags
    ICC_IA64_INSTALLED=0		#
    ICC_INTEL64_INSTALLED=0		#
    IFORT_IA32_INSTALLED=0		# 
    IFORT_IA64_INSTALLED=0		# 
    IFORT_INTEL64_INSTALLED=0		# 
    IDB_IA32_INSTALLED=0		#
    IDB_IA64_INSTALLED=0		#
    IDB_INTEL_INSTALLED=0		#
    MKL_IA32_INSTALLED=0		#
    MKL_IA64_INSTALLED=0		#
    MKL_INTEL64_INSTALLED=0		#
    TBB_IA32_INSTALLED=0		#
    TBB_IA64_INSTALLED=0		#
    TBB_INTEL64_INSTALLED=0		#
    PRESERVE_FORTRAN=0
    PRESERVE_ICC=0
    INSTALLED_PRODS=""
    # RPM METHOD
    #while INSTALLED_RPM_LIST="$(rpm -qa | grep -e intel-cproc${PKGNUM}-${VERSION} -e intel-cprof${PKGNUM}-${VERSION} -e intel-cproidb${PKGNUM}-${VERSION} -e intel-cpromklibdev${PKGNUM}-${VERSION} -e intel-cproipplibdev${PKGNUM}-${VERSION} -e intel-cprotbb${PKGNUM}-${VERSION} | sort | uniq)" && [ -n "$INSTALLED_RPM_LIST" ] ; do
    #while INSTALLED_RPM_LIST="$(rpm -qa | grep -e 
    # old non-RPM method - INSTALLED_PRODS="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' | grep ${PKGNUM}-${VERSION})"
    # New non-RPM Method

  # while INSTALLED_PRODS="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' | grep -e intel-cproc${PKGNUM}-${VERSION} -e intel-cprof${PKGNUM}-${VERSION} -e intel-cproidb${PKGNUM}-${VERSION} -e intel-cpromklibdev${PKGNUM}-${VERSION} -e intel-cproipplibdev${PKGNUM}-${VERSION} -e intel-cprotbb${PKGNUM}-${VERSION} | sort | uniq)" && [ -n "INSTALLED_PRODS" ]; do
  INSTALLED_PRODS=$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' | grep -o -e "intel-cproc${PKGNUM}-${VERSION}" -e "intel-cprof${PKGNUM}-${VERSION}" -e "intel-cproidb${PKGNUM}-${VERSION}" -e "intel-cpromklibdev${PKGNUM}-${VERSION}" -e "intel-cproipplibdev${PKGNUM}-${VERSION}" -e "intel-cprotbblib${PKGNUM}-${VERSION}" -e "intel-cproipp${PKGNUM}lp32-${VERSION}" | sort | uniq)
    INDEX=0
    DISPLAY_HEADER=0 
       
    VPRINT "DISPLAY_NON_RPM_MENU()- function post-initialization - INSTALLED_PRODS=<$INSTALLED_PRODS>"
    if [ "$INSTALLED_PRODS" = "" ]; then
        if [ "$DEFAULT_MODE" != 1 ]; then
	    echo
	    if [ "$ROOT_USER" = 0 ] ; then
	        echo "$UNS_STRING_18"
	        echo
	    else
	        echo "$UNS_STRING_16"
	        echo
	    fi
	fi
        # exit
        TINI_SCRIPT
    fi
 
    if [ -n "$INSTALLED_PRODS" ]; then
	DISPLAY_HEADER=1
    fi

    if [ "$DISPLAY_HEADER" = 1 ] ; then
	VPRINT "$0: $LOCAL_VERSION"
       	echo
       	# Which of the following would you like to uninstall?
	echo "$UNS_STRING_4"
	echo 
       	DISPLAY_HEADER=0 
    fi
    echo
    if [ -n "$INSTALLED_PRODS" ]; then
        # let "INDEX += 1"
        # 0.    Uninstall All Intel(R) Compiler Professional $PACKAGE_NUMBER Components
        echo "$UNS_STRING_5 $PACKAGE_NUMBER"
        UNINSTALL_ALL_CHOICE=1 	
    fi
    for THIS_PROD in $INSTALLED_PRODS; do
        PROD=$(grep -e "$THIS_PROD" $INTEL_SDP_PRODUCTS_DB)
       	PACKAGEID="$(echo $PROD | cut -d':' -f2)"
       	RPMNAME="$(echo $PROD | cut -d':' -f3 | cut -d"-" -f1-3)"
       	ARCH="$(echo $PROD | cut -d':' -f3 | cut -d"." -f3)"
       	LOCATION="$(echo $PROD | cut -d':' -f4)"
       	LOG_FILE="$(echo $PROD | cut -d':' -f5)"
	VPRINT "DISPLAY_NON_RPM_MENU - initial CProC 'dual' check"
	VPRINT "L739 - Before ARCH=<$ARCH>"
	RESULT1="$(echo $RPMNAME | grep cproc${PKGNUM}-${VERSION}-1.i486)"
	if [ -n "$RESULT1" ]; then
	    ICC_IA32_INSTALLED=1
            RESULT1A="$(cat $INTEL_SDP_PRODUCTS_DB | egrep intel-cproc${PKGNUM}-${VERSION}-1.x86_64)"
	    if [ -n "$RESULT1A" ]; then ARCH=dual; fi
        fi
	VPRINT "L746 - After ARCH=<$ARCH>"
	RESULT1="$(echo $RPMNAME | grep cproc${PKGNUM}-${VERSION}-1.ia64)"
	if [ -n "$RESULT1" ]; then
	    ICC_IA64_INSTALLED=1
        fi
	RESULT1="$(echo $RPMNAME | grep cproc${PKGNUM}-${VERSION}-1.x86_64)"
	if [ -n "$RESULT1" ]; then
	    ICC_INTEL64_INSTALLED=1
            RESULT1A="$(cat $INTEL_SDP_PRODUCTS_DB | egrep intel-cproc${PKGNUM}-${VERSION}-1.i486)"
	    if [ -n "$RESULT1A" ]; then ARCH=dual; fi
        fi
	RESULT2="$(echo $RPMNAME | grep cprof${PKGNUM}-${VERSION}-1.i486)"
	if [ -n "$RESULT2" ]; then
	    IFORT_IA32_INSTALLED=1
            RESULT1A="$(cat $INTEL_SDP_PRODUCTS_DB | egrep intel-cprof${PKGNUM}-${VERSION}-1.x86_64)"
	    if [ -n "$RESULT1A" ]; then ARCH=dual; fi
        fi
	RESULT2="$(echo $RPMNAME | grep cprof${PKGNUM}-${VERSION}-1.ia64)"
	if [ -n "$RESULT2" ]; then
	    IFORT_IA64_INSTALLED=1
        fi
	RESULT2="$(echo $RPMNAME | grep cprof${PKGNUM}-${VERSION}-1.x86_64)"
	if [ -n "$RESULT2" ]; then
	    IFORT_INTEL64_INSTALLED=1
            RESULT1A="$(cat $INTEL_SDP_PRODUCTS_DB | egrep intel-cprof${PKGNUM}-${VERSION}-1.i486)"
	    if [ -n "$RESULT1A" ]; then ARCH=dual; fi
        fi
	
	# VPRINT "DISPLAY_NON_RPM_MENU - Pre-RESULT_ZERO - RPMNAME=<$RPMNAME>"
        RESULT_ZERO=$(grep "$RPNAME" $INTEL_SDP_PRODUCTS_DB)
	# VPRINT "DISPLAY_NON_RPM_MENU - RESULT_ZERO=<$RESULT_ZERO>"
	RESULT_ZERO_A=$(echo $RESULT_ZERO | grep x86_64)
	RESULT_ZERO_B=$(echo $RESULT_ZERO | grep i486)
	# VPRINT "DISPLAY_NON_RPM_MENU - RESULT_ZERO_A=<$RESULT_ZERO_A>"
	# VPRINT "DISPLAY_NON_RPM_MENU - RESULT_ZERO_B=<$RESULT_ZERO_B>"
	if [ -n "$RESULT_ZERO_A" ] && [ -n "RESULT_ZERO_B" ]; then
            ARCH=dual
	    VPRINT "DISPLAY_NON_RPM_MENU - POST_RESULT_ZERO - ARCH=<$ARCH>"
        fi
        UPDATE_DISPLAY_VARIABLES 
       	let "INDEX += 1"
        echo "${INDEX}.      ${DISPLAY_NAME}" 
	if [ "$DISPLAY_NAME2" != "" ]; then
            echo -e "        ${DISPLAY_NAME2}" 
        fi
        RESULT1=$(echo $RPMNAME | grep intel-cproc${PKGNUM}-${VERSION})
	if [ -n "$RESULT1" ]; then
	    #  (May be required for Intel(R) MKL, Intel(R) TBB, 
	    #     or Intel(R) IPP)
	    echo "$UNS_STRING_6"
	fi
        RESULT1=$(echo $RPMNAME | grep intel-cprof${PKGNUM}-${VERSION})
	if [ -n "$RESULT1" ]; then
	    if [ "$IFORT_IA32_INSTALLED" = 1 ] || \
	        [ "$IFORT_IA64_INSTALLED" = 1 ] || \
	        [ "$IFORT_INTEL64_INSTALLED" = 1 ]; then
	        #         (May be required for Intel(R) MKL)
	        echo "$UNS_STRING_7"
	    fi
	fi
	#echo "                ( $LOCATION )"
    done
    MAX_INDEX=$INDEX 
    if [ "$MAX_INDEX" = 0 ]; then
	TINI_SCRIPT
    fi
    echo
    # x.    Exit
    echo "$UNS_STRING_8"
    echo
    # Please type a selection:    
    echo -n "$UNS_STRING_9"
    REPEAT_LOOP=1
    while [ "$REPEAT_LOOP" = "1" ]; do
    	read CHOICE
       	REPEAT_LOOP=0
    	if [ "$CHOICE" = "x" ]; then
       	    echo
            # Exiting uninstallation ...
            echo "$UNS_STRING_10"
            TINI_SCRIPT
        fi
    	if [ -n "$CHOICE" ] && [ $CHOICE = 0 ]; then
            UNINSTALL_ALL_CHOICE=1
            UNINSTALL_ALL_NON_RPM 
            TINI_SCRIPT
        fi
    	if [ -n $CHOICE ] && [ $CHOICE -gt 0 ] &> /dev/null && [ $CHOICE -lt $(($INDEX+1)) ]; then
	    echo
        else
	    REPEAT_LOOP=1
            echo
	    # inappropriate choice. try 0, x, or the number of a component
	    echo "$UNS_STRING_15"
    	    # Please type a selection:    
	    echo -n "$UNS_STRING_9"
    	fi
    done

    INDEX=0
    for PROD in $INSTALLED_PRODS; do
        let "INDEX += 1"
	if [ "$INDEX" = "$CHOICE" ]; then
            # check if this is a collision uninstall 
            PACKAGEID="$(echo $PROD | cut -d':' -f2)"
            RPMNAME="$(echo $PROD | cut -d':' -f3)"
            RPM_ARCH="$(echo $RPMNAME | cut -d'.' -f3)"
            LOCATION="$(echo $PROD | cut -d':' -f4)"
            LOG_FILE="$(echo $PROD | cut -d':' -f5)"
            RESULT1="$(echo $RPMNAME | grep cproc${PKGNUM}-${VERSION})"
	    # if this is cproc, set up for protection of equivalent cprof
	    if [ -n "$RESULT1" ]; then
	        if [ "$IFORT_IA32_INSTALLED" = 1 ] || [ "$IFORT_IA64_INSTALLED" = 1 ] \
		    || [ "$IFORT_INTEL64_INSTALLED" = 1 ]; then
		    PRESERVE_FORTRAN=1
                fi
            fi
	    if [ -n "$RESULT1" ]; then
	        # if this is cproc, set up for enforcement of compiler to be installed for
		#  mkl, ipp, or tbb 
	        if [ "$MKL_IA32_INSTALLED" = 1 ] || \
		    [ "$MKL_IA64_INSTALLED" = 1 ] || \
		    [ "$MKL_INTEL64_INSTALLED" = 1 ] || \
		    [ "$IPP_IA32_INSTALLED" = 1 ] || \
		    [ "$IPP_IA64_INSTALLED" = 1 ] || \
                    [ "$IPP_LP32_INSTALLED" = 1 ] || \
		    [ "$IPP_INTEL64_INSTALLED" = 1 ] || \
		    [ "$TBB_IA32_INSTALLED" = 1 ] || \
		    [ "$TBB_IA64_INSTALLED" = 1 ] || \
		    [ "$TBB_INTEL64_INSTALLED" = 1 ]; then
		    local ARCH_TEST=$(echo "$INSTALLED_PRODS" | grep -e 'ipp' -e 'tbb' -e 'mkl' | grep "$RPM_ARCH")
		    local ARCH_TEST2=$(echo "$INSTALLED_PRODS" | grep 'tbb' | grep 'noarch')
		    if [ -n "$ARCH_TEST" ] || [ -n "$ARCH_TEST2" ]; then
		        # Cannot remove C/C++ Compiler until C/C++ compiler dependent product
		        # components IPP, TBB, and/or MKL are uninstalled.
		        # Press ENTER to continue
		        echo $UNS_STRING_2
		        read CONTINUE
		        break
		    fi
                fi
            fi
	    # if this is cprof, set up for protection of equivalent cproc
	    RESULT3="$(echo $RPMNAME | grep intel-cprof${PKGNUM}-${VERSION})"
	    if [ -n "$RESULT3" ]; then 
	        if [ "$ICC_IA32_INSTALLED" = 1 ] || [ "$ICC_IA64_INSTALLED" = 1 ] \
		    || [ "$ICC_INTEL64_INSTALLED" = 1 ]; then
	            PRESERVE_ICC=1
	        fi
	    fi
	    if [ -n "$RESULT3" ]; then
	        # if this is cprof, set up for enforcement of MKL requirement
	        if [ "$MKL_IA32_INSTALLED" = 1 ] || \
		    [ "$MKL_IA64_INSTALLED" = 1 ] || \
		    [ "$MKL_INTEL64_INSTALLED" = 1 ]; then
                    echo
		    local ARCH_TEST=$(echo "$INSTALLED_PRODS" | grep cpro | grep mkl | grep "$RPM_ARCH")
		    if [ -n "$ARCH_TEST" ]; then
		        # Cannot remove Fortran Compiler until Fortran compiler dependent
		        # MKL product component is uninstalled.
		        # Press ENTER to continue"
		        echo "$UNS_STRING_3"
		        read CONTINUE
		        break
		    fi
                fi
            fi

	    # no longer need to add check for removal of over-written MKLs and IDBs

            case "$RPMNAME" in
                 intel-cproc${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling component $RPMNAME ..."
		     if [ "$PRESERVE_FORTRAN" = 1 ]; then
		          THIS_PROD_LIST="$RPMNAME intel-cprocsdk${PKGNUM}-${VERSION}-1 intel-cproc${PKGNUM}-${VERSION}-1"
                     else
	                  THIS_PROD_LIST="$RPMNAME intel-cprocsdk${PKGNUM}-${VERSION}-1 intel-cproc${PKGNUM}-${VERSION}-1"
	                  THIS_PROD_LIST="$THIS_PROD_LIST intel-cprolib${PKGNUM}-${VERSION}-1 intel-cprolibdev${PKGNUM}-${VERSION}-1"
			  VPRINT "THIS_PROD_LIST = <$THIS_PROD_LIST>"
                     fi	
                     # UNINSTALL_CPROC_RPM_AND_ITS_DEPENDENCIES
		     #continue
                     ;;
                 intel-cprof${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $RPMNAME"
		     if [ "$PRESERVE_ICC" = 1 ]; then
		         THIS_PROD_LIST="$RPMNAME intel-cprofsdk${PKGNUM}-${VERSION}-1 intel-cproflib${PKGNUM}-${VERSION}-1"
                     else
		         THIS_PROD_LIST="$RPMNAME intel-cprofsdk${PKGNUM}-${VERSION}-1 intel-cproflib${PKGNUM}-${VERSION}-1"
	                 THIS_PROD_LIST="$THIS_PROD_LIST intel-cprolib${PKGNUM}-${VERSION}-1 intel-cprolibdev${PKGNUM}-${VERSION}-1"
			 VPRINT "THIS_PROD_LIST = <$THIS_PROD_LIST>"
                     fi	
		     VPRINT "THIS_PROD_LIST = <$THIS_PROD_LIST>"
	             #UNINSTALL_CPROF_RPM_AND_ITS_DEPENDENCIES
		     #continue
                     ;;
                 intel-cproidb${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $RPMNAME"
                     REMOVE_IDB_LINKS
		     if [ "$RPM_ARCH" != "ia64" ]; then
		         IDBCDT_RESULT=$(grep intel-cproidbcdt${PKGNUM}-${VERSION} $INTEL_SDP_PRODUCTS_DB)
			 if [ -n "$IDBCDT_RESULT" ]; then
	                     THIS_PROD_LIST="$RPMNAME intel-cproidbsdk${PKGNUM}-${VERSION} intel-cproidbcdt${PKGNUM}-${VERSION}"
		         else
			     VPRINT "No idbcdt found ... must have been a Fortran IDB install"
	                     THIS_PROD_LIST="$RPMNAME intel-cproidbsdk${PKGNUM}-${VERSION}"
		         fi
		     else
			 VPRINT "No IDBCDT for IA64"
	                 THIS_PROD_LIST="$RPMNAME intel-cproidbsdk${PKGNUM}-${VERSION}"
		     fi
		     VPRINT "THIS_PROD_LIST = <$THIS_PROD_LIST>"
                     ;;
                 intel-cpromklibdev${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $RPMNAME"
	             THIS_PROD_LIST="$RPMNAME intel-cpromklib${PKGNUM}-${VERSION} intel-cpromkl${PKGNUM}-${VERSION}"
		     VPRINT "THIS_PROD_LIST = <$THIS_PROD_LIST>"
                     ;;
                 intel-cproipplibdev${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $RPMNAME"
                     REMOVE_IPP_LINKS
                     THIS_PROD_LIST="$RPMNAME intel-cproipp${PKGNUM}-${VERSION} intel-cproipplib${PKGNUM}-${VERSION}"
		     [ "x$CPIPP_INSTALLED" == "x1" ] && THIS_PROD_LIST="$THIS_PROD_LIST intel-cproc${PKGNUM}crypto_ipp-${VERSION}"
		     VPRINT "THIS_PROD_LIST = <$THIS_PROD_LIST>"
                     ;;
                 intel-cproipp${PKGNUM}lp32-${VERSION}* )
	             VPRINT "Uninstalling $RPMNAME"
                     THIS_PROD_LIST="$RPMNAME"
                     [ "x$CPIPP_INSTALLED" == "x1" ] && THIS_PROD_LIST="$THIS_PROD_LIST intel-cproc${PKGNUM}crypto_ipp-${VERSION}"
                     VPRINT "THIS_PROD_LIST = <$THIS_PROD_LIST>"
                     ;;
                 intel-cprotbblib${PKGNUM}-${VERSION}* )
	             VPRINT "Uninstalling $RPMNAME"
                     REMOVE_TBB_LINKS
	             THIS_PROD_LIST="$RPMNAME intel-cprotbblibdev${PKGNUM}-${VERSION}"
		     VPRINT "THIS_PROD_LIST = <$THIS_PROD_LIST>"
                     ;;
                 * )
	             VPRINT "No match for RPMNAME=<$RPMNAME>"
	             THIS_PROD_LIST=""
                     continue
                     ;;
             esac
	     if [ -n "$THIS_PROD_LIST" ]; then
                 for THIS_NONRPM_PROD in $THIS_PROD_LIST
	         do
	             VPRINT "THIS_NONRPM_PROD=<$THIS_NONRPM_PROD>"
                     PROD_INSTANCE_LIST="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' | grep $THIS_NONRPM_PROD)"
	             VPRINT "PROD_INSTANCE_LIST=<$PROD_INSTANCE_LIST>"
		     for THIS_PROD_INSTANCE in $PROD_INSTANCE_LIST
		     do
		         VPRINT "Executing UNINSTALL_NON_RPM THIS_PROD_INSTANCE=<$THIS_PROD_INSTANCE>"
			 if [ "$DEBUG_MODE" = 1 ]; then
                             echo "DEBUG - Press ENTER to continue"
			     read CONTINUE
			 fi
	                 UNINSTALL_NON_RPM $THIS_PROD_INSTANCE
		     done
	         done
	     fi
	     break
        fi
     done
}

# ------------------------------------------------------------------------
# if verbose mode is enabled print the arg text
VPRINT () 
{
    if [ "$VERBOSE_MODE" = 1 ]; then echo $* ; fi
}

# ------------------------------------------------------------------------
# remove all rpm files for PKGNUM
UNINSTALL_ALL_RPM ()
{
    VPRINT "UNINSTALL_ALL_RPM()"
    local UNINSTALL_ALL_RPM_LOG=/tmp/.$$.uninstall.log

    VPRINT "UNINSTALL_ALL_RPM() - log file is here <$UNINSTALL_ALL_RPM_LOG>"
    # Get install dir from packages
    # build symlink removal list
    ERASE_LIST=$(rpm -qa | grep -e 'intel-cpro' | grep -e ${PKGNUM} | grep -e ${VERSION})
    VPRINT "ERASE_LIST=<$ERASE_LIST>"

    VPRINT "Checking for TBB removals ..."
    local RESULT1="$(echo $ERASE_LIST  | egrep -e 'intel-cprotbb' | egrep -e 'tbb')"
    if [ -n "$RESULT1" ]; then
        VPRINT "RPM removal of TBB symlinks in progress ..."
	TBB_RPM=$(rpm -qa | grep -e 'intel-' | grep -e 'cprotbb' | grep ${PKGNUM}-${VERSION})
        REMOVE_TBB_LINKS
    fi

    VPRINT "Checking for IDB removals ..."
    local RESULT1="$(echo $ERASE_LIST  | egrep -e 'intel-cproidb')"
    if [ -n "$RESULT1" ]; then
        VPRINT "RPM removal of IDB symlinks in progress ..."
	REMOVE_IDB_LINKS
    fi

    # VPRINT "Checking for *support removals ..." - obsolete

    if [ -n "$ERASE_LIST" ]; then
        if [ "$VERBOSE_MODE" = 1 ]; then
	    VPRINT "RPM Erase list=<$ERASE_LIST>"
		echo "Confirm erase: Remove these RPMs? ($ERASE_LIST) "
		echo
		echo -n "       [yes/NO] : "
		read CONFIRM_ERASE
		if [ "$CONFIRM_ERASE" = "yes" ]; then
		    echo
		    echo "$UNS_STRING_21"
	            rpm -e --allmatches $ERASE_LIST 2> $UNINSTALL_ALL_RPM_LOG
	        else
		    echo "User chose not to erase this list of RPMs"
                    echo
	        fi
        else
		echo
		echo "$UNS_STRING_21"
	        rpm -e --nodeps --allmatches $ERASE_LIST > /dev/null 2> $UNINSTALL_ALL_RPM_LOG
        fi
        RESULT=$?
    else
        VPRINT "$0: ERROR - No RPMs found in UNINSTALL_ALL_RPM"
        TINI_SCRIPT    
    fi

    if [ "$RESULT" != 0 ]; then
        echo "$0: ERROR in UNINSTALL_ALL_RPM" >&2
	echo "Results in log file $UNINSTALL_ALL_RPM_LOG"
        cat $UNINSTALL_ALL_RPM_LOG >&2
        exit 1
    else
        TINI_SCRIPT    
    fi
    
}

# ------------------------------------------------------------------------
# removal all non-rpm installs
UNINSTALL_ALL_NON_RPM ()
{
    VPRINT "UNINSTALL_ALL_NON_RPM()"
    INDEX=1
    INSTALLED_PRODS=""
    INSTALLED_PRODS="$(cat $INTEL_SDP_PRODUCTS_DB | egrep '<:' | grep 'intel-cpro' | grep ${PKGNUM} | grep ${VERSION})"
    VPRINT "PKGNUM=$PKGNUM"
    VPRINT "INSTALLED_PRODS=$INSTALLED_PRODS"
    REMOVE_TBB_LINKS
    REMOVE_IPP_LINKS
    REMOVE_IDB_LINKS
    for PROD in $INSTALLED_PRODS; do
        PACKAGEID="$(echo $PROD | cut -d':' -f2)"
        RPMNAME="$(echo $PROD | cut -d':' -f3)"
        LOCATION="$(echo $PROD | cut -d':' -f4)"
        LOG_FILE="$(echo $PROD | cut -d':' -f5)"
        UPDATE_DISPLAY_VARIABLES
        let "INDEX += 1"
    done
    let "INDEX -= 1"
                                                                                                                             
    for PROD in $INSTALLED_PRODS; do
        VPRINT "------------------------------------------------------------------------------"
        VPRINT "uninstalling $PROD from list of ${VERSION} package ${PKGNUM} components ..."
        VPRINT "------------------------------------------------------------------------------"
        UNINSTALL_NON_RPM $PROD
    done
}


# set product labels to match component contents
UPDATE_DISPLAY_VARIABLES ()
{
# RPM names for 11.1 will look something like this
# intel-cpromklib008-11.1-1.i486.rpm - run-time libs
# intel-cpromklibdev008-11.1-1.i486.rpm - devel libs
# intel-cpromkl008-11.1-1.noarch.rpm - shared content 
# intel-cproipplib008-11.1-1.i486.rpm - run-time libs
# intel-cproipplibdev008-11.1-1.i486.rpm - devel libs
# intel-cproipp008-11.1-1.noarch.rpm - shared content
# intel-cproipp008lp32-11.1-1.noarch.rpm - Atom optimized content
# intel-cprotbblib008-11.1-1.noarch.rpm - all redist content
# intel-cprotbblibdev008-11.1-1.noarch.rpm - all non-redist content
# intel-cprotbb008-11.1-1.i486.rpm - all content (not split)
# intel-cproidbsdk008-11.1-1.noarch.rpm - debugger shared content
# intel-cproidbcdt008-11.1-1.noarch.rpm - debugger CDT shared content (C++)
# intel-cproidb008-11.1-1.i486.rpm - debugger app and arch-specific files
# intel-cprolib008-11.1-1.i486.rpm - C++ run-time libs (shared with Fortran)
# intel-cprolibdev008-11.1-1.i486.rpm - C++ devel libs (shared with Fortran)
# intel-cproc008-11.1-1.i486.rpm - C++ app and arch-specific files
# intel-cprocsdk008-11.1-1.noarch.rpm - C++ shared content
# intel-cprof008-11.1-1.i486.rpm - Fortran app and arch-specific files
# intel-cproflib008-11.1-1.i486.rpm - Fortran run-time libs
# intel-cprofsdk008-11.1-1.noarch.rpm - Fortran shared files

   VPRINT "UPDATE_DISPLAY_VARIABLES()"

# filter out all auxiliary RPMs - core packages include only these:
#  (where 008 is an example package number)
# -  intel-cproc008-11.1-1 - C++ compiler
# --- requires intel-cprolib, intel-cprolibdev, intel-cprocsdk
# -  intel-cprof008-11.1-1 - Fortran compiler
# --- requires intel-cprolib, intel-cprolibdev, intel-cprofsdk, intel-cproflib
# -  intel-cproidb008-11.1-1 - debugger
# --- requires intel-cproidbsdk
# -  intel-cpromklibdev008-11.1-1 - MKL
# --- requires intel-cpromklib, intel-cpromkl, intel-cprolibdev
# -  intel-cproipplibdev008-11.1-1 - IPP
# --- requires intel-cproipplib, intel-cproipp, intel-cprolibdev
# -  intel-cprotbb008-11.1-1 - TBB (no auxiliary packages)
# --- requires intel-cprolibdev

   VERSION=$(echo "$RPMNAME" | cut -d'-' -f3)
   PRODUCT=$(echo "$RPMNAME" | grep -o -E "(intel-cproc${PKGNUM}-${VERSION}|intel-cprof${PKGNUM}-${VERSION}|intel-cproidb${PKGNUM}-${VERSION}|intel-cpromklibdev${PKGNUM}-${VERSION}|intel-cproipplibdev${PKGNUM}-${VERSION}|intel-cprotbblib${PKGNUM}-${VERSION})|intel-cproipp${PKGNUM}lp32-${VERSION}" | sort | uniq )
   VPRINT "UPDATE_DISPLAY_VARIABLES()-PRODUCT=$PRODUCT"
   VPRINT "UPDATE_DISPLAY_VARIABLES()-VERSION=$VERSION"
   TEMP_ARCH=$ARCH
   ARCH=$(echo "$RPMNAME" | grep -o -E '(i486|ia64|x86_64|noarch)')
   if [ "$ARCH" = "" ] && [ "$TEMP_ARCH" != "" ]; then
       ARCH=$TEMP_ARCH
   fi
   VPRINT "UPDATE_DISPLAY_VARIABLES()-ARCH=$ARCH"

   if echo  "$RPMNAME" | egrep -e 'cproc' &> /dev/null; then
        COMP_TYPE="$UNS_STRING_43"
   else
        COMP_TYPE="$UNS_STRING_44"
   fi
   
   signon=""
   signon2=""

   VPRINT "UPDATE_DISPLAY_VARIABLES - PRODUCT CHECK on <$PRODUCT>"
   case "$PRODUCT" in
   intel-cproipplibdev${PKGNUM}-${VERSION} )
        case "$ARCH" in
           dual )
               IPP_IA32_INSTALLED=1
               IPP_INTEL64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="${UNS_STRING_61}"
                       signon2="AND ${UNS_STRING_63}"
               else
                       signon="${UNS_STRING_58}"
                       signon2="AND ${UNS_STRING_60}"
               fi
               ;;
           i486 )
               IPP_IA32_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_61"
               else
                       signon="$UNS_STRING_58"
               fi
               ;;
           ia64 )
               IPP_IA64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_62"
               else
                       signon="$UNS_STRING_59"
               fi
               ;;
           x86_64 )
               IPP_INTEL64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_63"
               else
                       signon="$UNS_STRING_60"
               fi
               ;;
           * )
               continue ;;
        esac
	if [ $NONRPM_SWITCH -eq 0 ]; then cpinstalled=$(rpm -qa | grep -e intel-cproc${PKGNUM}crypto_ipp-${VERSION} 2>/dev/null)
	else
	    cpinstalled=$(cat $INTEL_SDP_PRODUCTS_DB | grep -e intel-cproc${PKGNUM}crypto_ipp-${VERSION} 2>/dev/null)
	fi
	if [ "x$cpinstalled" != "x" ]; then
	    CPIPP_INSTALLED=1
    	    if [ -n "$signon2" ]; then
                if [ "$BETA_PACKAGE" = 1 ];  then
		    signon2="$signon2\n        AND ${UNS_STRING_108}"
		else
		    signon2="$signon2\n        AND ${UNS_STRING_109}"
		fi
            else
                if [ "$BETA_PACKAGE" = 1 ];  then
		    signon2="AND ${UNS_STRING_108}"
		else
		    signon2="AND ${UNS_STRING_109}"
		fi
	    fi
            
	fi    
        ;;
   intel-cproipp${PKGNUM}lp32-${VERSION} )
   # it can be presented on IA-32 only (within Atom tools package)
   # no other ARCH here
        case "$ARCH" in
           i486 )
               IPP_LP32_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_111"
               else
                       signon="$UNS_STRING_110"
               fi
               ;;
           * )
               continue ;;
        esac
        if [ $NONRPM_SWITCH -eq 0 ]; then cpinstalled=$(rpm -qa | grep -e intel-cproc${PKGNUM}crypto_ipp-${VERSION} 2>/dev/null)
	else
	    cpinstalled=$(cat $INTEL_SDP_PRODUCTS_DB | grep -e intel-cproc${PKGNUM}crypto_ipp-${VERSION} 2>/dev/null)
	fi
	if [ "x$cpinstalled" != "x" ]; then
	    CPIPP_INSTALLED=1
            if [ "$BETA_PACKAGE" = 1 ];  then
                signon2="AND ${UNS_STRING_108}"
            else
                signon2="AND ${UNS_STRING_109}"
            fi
	fi    
        ;;
   intel-cprotbblib${PKGNUM}-${VERSION} )

	local THIS_ARCH=$(uname -m)
	case $THIS_ARCH in
    	   x86_64 )
               TBB_IA32_INSTALLED=1
               TBB_INTEL64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="${UNS_STRING_73}"
		       signon2="AND ${UNS_STRING_75}"
               else
                       signon="${UNS_STRING_70}"
		       signon2="AND ${UNS_STRING_72}"
               fi
               ;;
           i686|i486 )
               TBB_IA32_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_73"
               else
                       signon="$UNS_STRING_70"
               fi
               ;;
           ia64 )
               TBB_IA64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_74"
               else
                       signon="$UNS_STRING_71"
               fi
               ;;
           * )
               continue ;;
        esac
        ;;
   intel-cproidb${PKGNUM}-${VERSION} )
            case "$ARCH" in
               dual )
                   IDB_IA32_INSTALLED=1
                   IDB_INTEL64_INSTALLED=1
                   if [ "$BETA_PACKAGE" = 1 ];  then
                           signon="${UNS_STRING_79}"
			   signon2="AND ${UNS_STRING_81}"
                   else
                           signon="${UNS_STRING_76}"
			   signon2="AND $UNS_STRING_78}"
                   fi
                   ;;
               i486 )
                   IDB_IA32_INSTALLED=1
                   if [ "$BETA_PACKAGE" = 1 ];  then
                           signon="$UNS_STRING_79"
                   else
                           signon="$UNS_STRING_76"
                   fi
                   ;;
               ia64 )
                   IDB_IA64_INSTALLED=1
                   if [ "$BETA_PACKAGE" = 1 ];  then
                           signon="$UNS_STRING_80"
                   else
                           signon="$UNS_STRING_77"
                   fi
                   ;;
               x86_64 )
                   IDB_INTEL64_INSTALLED=1
                   if [ "$BETA_PACKAGE" = 1 ];  then
                           signon="$UNS_STRING_81"
                   else
                           signon="$UNS_STRING_78"
                   fi
                   ;;
               * )
                   continue ;;
            esac
        ;;
   intel-cpromklibdev${PKGNUM}-${VERSION} )
            case "$ARCH" in
               dual )
	           MKL_IA32_INSTALLED=1
	           MKL_INTEL64_INSTALLED=1
                   if [ "$BETA_PACKAGE" = 1 ];  then
                           signon="${UNS_STRING_85}"
			   signon2="AND ${UNS_STRING_87}"
                   else
                           signon="${UNS_STRING_82}"
			   signon2="AND ${UNS_STRING_84}"
                   fi
                   ;;
               i486 )
	           MKL_IA32_INSTALLED=1
                   if [ "$BETA_PACKAGE" = 1 ];  then
                           signon="$UNS_STRING_85"
                   else
                           signon="$UNS_STRING_82"
                   fi
                   ;;
               ia64 )
	           MKL_IA64_INSTALLED=1
                   if [ "$BETA_PACKAGE" = 1 ];  then
                           signon="$UNS_STRING_86"
                   else
                           signon="$UNS_STRING_83"
                   fi
                   ;;
               x86_64 )
	           MKL_INTEL64_INSTALLED=1
                   if [ "$BETA_PACKAGE" = 1 ];  then
                           signon="$UNS_STRING_87"
                   else
                           signon="$UNS_STRING_84"
                   fi
                   ;;
               * )
                   continue ;;
            esac
            ;;
   intel-cproc${PKGNUM}-${VERSION} )
        case "$ARCH" in
           dual )
               ICC_IA32_INSTALLED=1
               ICC_INTEL64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="${UNS_STRING_97}"
		       signon2="AND ${UNS_STRING_99}"
               else
                       signon="${UNS_STRING_94}"
		       signon2="AND ${UNS_STRING_96}"
               fi
               ;;
           i486 )
               ICC_IA32_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_97"
               else
                       signon="$UNS_STRING_94"
               fi
               ;;
           ia64 )
               ICC_IA64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_98"
               else
                       signon="$UNS_STRING_95"
               fi
               ;;
           x86_64 )
               ICC_INTEL64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_99"
               else
                       signon="$UNS_STRING_96"
               fi
               ;;
           * )
               continue ;;
        esac
        ;;
   intel-cprof${PKGNUM}-${VERSION} )
        case "$ARCH" in
           dual )
               IFORT_IA32_INSTALLED=1
               IFORT_INTEL64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="${UNS_STRING_103}"
		       signon2="AND ${UNS_STRING_105}"
               else
                       signon="${UNS_STRING_100}"
		       signon2="AND ${UNS_STRING_102}"
               fi
               ;;
           i486 )
               IFORT_IA32_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_103"
               else
                       signon="$UNS_STRING_100"
               fi
               ;;
           ia64 )
               IFORT_IA64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_104"
               else
                       signon="$UNS_STRING_101"
               fi
               ;;
           x86_64 )
               IFORT_INTEL64_INSTALLED=1
               if [ "$BETA_PACKAGE" = 1 ];  then
                       signon="$UNS_STRING_105"
               else
                       signon="$UNS_STRING_102"
               fi
               ;;
           * )
               continue ;;
        esac
        ;;
   * )
        signon="internal component (ignore)"
        VPRINT "UPDATE_DISPLAY_VARIABLES() - PRODUCT=<$PRODUCT> no match - "; 
        continue 
   ;;
   esac
   
   # case "$ARCH" in
   # i686 )
   #       signon="$signon $UNS_STRING_52 $beta"
   # ;;
   # ia64 )
   #       signon="$signon $UNS_STRING_53 $beta"
   # ;;
   # x86_64 )
   #       signon="$signon $UNS_STRING_54 $beta"
   # ;;
   # * )
   #       continue ;;
   # esac
   DISPLAY_NAME="$signon"
   DISPLAY_NAME2="$signon2"
}


# ------------------------------------------------------------------------
# process all command line arguments
PROCESS_ARGS ()
{
    # --default  and --verbose added added
    VPRINT "PROCESS_ARGS() - SCRIPT_ARGS=$SCRIPT_ARGS"

    for THIS_ARG in $SCRIPT_ARGS
    do
        VPRINT "PROCESS_ARGS() - THIS_ARG=$THIS_ARG"
        case "$THIS_ARG" in
            --nonrpm )
                NONRPM_SWITCH=1
	        ;;
            --default )
                DEFAULT_MODE=1
	        ;;
            --verbose )
                VERBOSE_MODE=1
	        ;;
            --debug )
                VERBOSE_MODE=1
                DEBUG_MODE=1	# for future use
		# DEBUG mode enabled - debug comments in ENGLISH only
		echo "$UNS_STRING_55"
	        ;;
            * )
                # Unknown option \'$SCRIPT_ARGS\'
		echo "$UNS_STRING_56 \'$SCRIPT_ARGS\'"
                echo
	       exit 1;;
            esac
    done
}

# ------------------------------------------------------------------------
# exit script
TINI_SCRIPT ()
{
    VPRINT "TINI_SCRIPT()"
    if [ -e "$UNINSTALL_ALL_RPM_LOG" ]; then
        rm -rf "$UNINSTALL_ALL_RPM_LOG" 2> /dev/null
    fi
    if [ -e "$RPM_UNS_LOG" ]; then
        rm -rf "$RPM_UNS_LOG" 2> /dev/null
    fi
    echo "Uninstall complete"
    exit
}

# ----------------------------------------------------
# Uninstallation Script Execution Starts Here
#-----------------------------------------------------

#clear
SCRIPT="$0"
SCRIPT_ARGS="$@"
RPM_UNS_LOG=/tmp/.$$.cpro_rpm_uninstall_log.txt
ARGS_NUM="$#"
SCRIPT_DIR="$(dirname $SCRIPT)"

if [ "$SCRIPT_DIR" = "." ]; then
    SCRIPT_DIR="$(pwd)"
else
    cd $SCRIPT_DIR
    SCRIPT_DIR="$(pwd)"
fi
#if [ "$1" = "--verbose" ]; then 
#    VERBOSE_MODE=1
#    shift
#fi

DEFAULT_MODE=0			# changed to 1 at command arg eval by "--default" command line switch
VERBOSE_MODE=0			# changed to 1 at command arg eval by "--verbose" command line switch
INTEL_SDP_PRODUCTS_DB=""	# location of flat file non-RPM product database
DEBUG_MODE=0			# for future use
EP_INSTALLED=0			# for future use
PRESERVE_FORTRAN=0		# mark if Fortran needs to be protected from C++ uninstall
PRESERVE_ICC=0			# mark if C++ needs to be protected from Fortran uninstall
LOCAL_VERSION="1.33-009g"	# for internal debug purposes only

ICC_IA32_INSTALLED=0		# initialize all installed component flags
ICC_IA64_INSTALLED=0		#
ICC_INTEL64_INSTALLED=0		#
IFORT_IA32_INSTALLED=0		# 
IFORT_IA64_INSTALLED=0		# 
IFORT_INTEL64_INSTALLED=0	# 
IDB_IA32_INSTALLED=0		#
IDB_IA64_INSTALLED=0		#
IDB_INTEL_INSTALLED=0		#
MKL_IA32_INSTALLED=0		#
MKL_IA64_INSTALLED=0		#
MKL_INTEL64_INSTALLED=0		#
TBB_IA32_INSTALLED=0		#
TBB_IA64_INSTALLED=0		#
TBB_INTEL64_INSTALLED=0		#

# This next string is modified during a non-RPM install to "NONRPM_SWITCH=1"
NONRPM_SWITCH=0
# This next string is initialized during the build process
# example: THIS_PACKAGEID=l_cprof_b_11.1.730
THIS_PACKAGEID=l_cproc_p_11.1.038
PACKAGE_NUMBER=$(echo $THIS_PACKAGEID | cut -f 4 -d_)
# 11.0  version - PKGNUM=$(echo $PACKAGE_NUMBER | tr -d .)
PKGNUM=$(echo $PACKAGE_NUMBER | cut -f 3 -d .)
PKG_VERSION=$(echo $PACKAGE_NUMBER | cut -f 1,2 -d .)
if [ "$VERSION" = "" ]; then VERSION="$PKG_VERSION" ; fi
PKG_TYPE=$(echo $THIS_PACKAGEID | cut -f 2 -d_)
#echo "PACKAGE_NUMBER=$PACKAGE_NUMBER --- PKGNUM=$PKGNUM --- PKG_TYPE=$PKG_TYPE"
## determine whether user is root or not.
if echo "$PACKAGEID" | grep -E '<:l_*_b' > /dev/null ; then
    beta="$UNS_STRING_45"
    BETA_PACKAGE=1
else
    beta=""
    BETA_PACKAGE=0
fi

RESULT="$(echo $0 | grep uninstall_cprof)"
if [ "$RESULT" != "" ]; then
    LANG_BASE="uninstall_cprof.txt"
else
    RESULT="$(echo $0 | grep uninstall_cproc)"
    if [ "$RESULT" != "" ]; then
        LANG_BASE="uninstall_cproc.txt"
    else
        LANG_BASE="uninstall_debugger.txt"
    fi
fi

# localization disabled for 11.1 initial release
# (this will be restored later in the release cycle)
#if [ "$LANG" != "" ]; then
#    case $LANG in
#        ja_JP.utf-8 | ja_JP.UTF-8 | ja_JP.utf8 | ja_JP.UTF8)
#            LANG_FILE=$SCRIPT_DIR/ja_JP/$LANG_BASE
#	    ;;
#        en_US.utf-8 | en_US.UTF-8)
#            LANG_FILE=$SCRIPT_DIR/en_US/$LANG_BASE
#	    ;;
#        * )
#            LANG_FILE=$SCRIPT_DIR/en_US/$LANG_BASE
#	    ;;
#    esac
#else
    LANG_FILE=$SCRIPT_DIR/en_US/$LANG_BASE
#fi

# if this file is missing something is broken
if [ -s "$LANG_FILE" ]; then
    source $LANG_FILE
else
    echo "Internal error: cannot find localization component"
    TINI_SCRIPT
fi

# one last test of localization - if this string is missing something is broken
if [ "$UNS_STRING_1" = "" ]; then
    echo "Internal error: localization string management malfunction"
    TINI_SCRIPT
fi

PROCESS_ARGS				# check command line arguments
IS_USER_ROOT				# determine if the user is 'root'
IS_RPM_PRESENT				# check if rpm utility can be found
GET_FLATFILE_DB_LOCATION		# find text file product database
CHECK_LOCAL_UNINSTALL			# check if uninstalling from actual bin dir
VPRINT "LOCAL_VERSION = $LOCAL_VERSION"	# report version

# if DEFAULT_MODE then remove everything with minimal noise unless error occurs
if [ "$DEFAULT_MODE" = 1 ] ; then
    if [ "$ROOT_USER" = 0 ] ; then
       VPRINT "non-RPM default mode"
       UNINSTALL_ALL_NON_RPM 
       #exit 0
       TINI_SCRIPT
    elif  [ ! "$RPM_NOT_FOUND" = 0 ] || [ "$NONRPM_SWITCH" = 1 ]; then
       VPRINT "non-RPM default mode"
       VPRINT  "executing UNINSTALL_ALL_NON_RPM"
       UNINSTALL_ALL_NON_RPM 
       #exit 0
       TINI_SCRIPT
    else 
       if [ "$VERBOSE_MODE" = 1 ]; then echo "RPM default mode"; fi
       UNINSTALL_ALL_RPM 
       exit 0
       TINI_SCRIPT
    fi 
    VPRINT "uninstall -  default mode - exiting"
    #exit 0
    TINI_SCRIPT
fi    

## If user is not root, perform uninstallation by querying the flat file database.
if [ "$ROOT_USER" = 0 ] ; then
	NON_RPM_BASED_UNINSTALLATION
else
	if  [ ! "$RPM_NOT_FOUND" = 0 ] || [ "$NONRPM_SWITCH" = 1 ]; then
		NON_RPM_BASED_UNINSTALLATION
	else
		RPM_BASED_UNINSTALLATION
	fi
fi

